@@ -5,6 +5,7 @@ import subprocess
 import sys
 import time
 
+import os
 from os.path import exists, join, split, dirname, abspath
 from traitlets import Unicode
 
@@ -16,6 +17,8 @@ from jupyter_client.kernelspec import (
 
 CACHE_TIMEOUT = 60
 
+CONDA_EXE = os.environ.get("CONDA_EXE", "conda")
+
 
 class CondaKernelSpecManager(KernelSpecManager):
     """ A custom KernelSpecManager able to search for conda environments and
@@ -51,9 +54,13 @@ class CondaKernelSpecManager(KernelSpecManager):
 
         if expiry is None or expiry < time.time():
             self.log.debug("[nb_conda_kernels] refreshing conda info")
+            # This is to make sure that subprocess can find 'conda' even if
+            # it is a Windows batch file---which is the case in non-root
+            # conda environments.
+            shell = CONDA_EXE == 'conda' and sys.platform.startswith('win')
             try:
-                p = subprocess.check_output(["conda", "info", "--json"]
-                                            ).decode("utf-8")
+                p = subprocess.check_output([CONDA_EXE, "info", "--json"],
+                                            shell=shell).decode("utf-8")
                 conda_info = json.loads(p)
             except Exception as err:
                 conda_info = None
@@ -167,10 +174,8 @@ class CondaKernelSpecManager(KernelSpecManager):
         if self._conda_info is None:
             return {}
 
-        if (
-            self._conda_kernels_cache_expiry is None or
-            self._conda_kernels_cache_expiry < time.time()
-           ):
+        if (self._conda_kernels_cache_expiry is None or
+            self._conda_kernels_cache_expiry < time.time()):
             self.log.debug("[nb_conda_kernels] refreshing conda kernelspecs")
             self._conda_kernels_cache = self._load_conda_kspecs()
             self._conda_kernels_cache_expiry = time.time() + CACHE_TIMEOUT
@@ -194,7 +199,7 @@ class CondaKernelSpecManager(KernelSpecManager):
                     "env": {},
                     "resource_dir": join(dirname(abspath(__file__)), "logos",
                                          "python")
-                 }
+                }
             elif info['language_key'] == 'r':
                 kspec = {
                     "argv": [executable, "--slave", "-e", "IRkernel::main()",
